@@ -9,7 +9,10 @@
 ---
 <!--END STABILITY BANNER-->
 
-A short description here.
+This library contains destinations for AWS CloudWatch Logs SubscriptionFilters. You
+can send log data to Kinesis Streams or Lambda Functions.
+
+See the documentation of the `logs` module for more information.
 '''
 import abc
 import builtins
@@ -23,6 +26,7 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
@@ -42,19 +46,31 @@ class KinesisDestination(
 
         # The code below shows an example of how to instantiate this type.
         # The values are placeholders you should change.
+        import aws_cdk.aws_iam as iam
         import aws_cdk.aws_kinesis as kinesis
         import aws_cdk.aws_logs_destinations as logs_destinations
         
+        # role: iam.Role
         # stream: kinesis.Stream
         
-        kinesis_destination = logs_destinations.KinesisDestination(stream)
+        kinesis_destination = logs_destinations.KinesisDestination(stream,
+            role=role
+        )
     '''
 
-    def __init__(self, stream: aws_cdk.aws_kinesis.IStream) -> None:
+    def __init__(
+        self,
+        stream: aws_cdk.aws_kinesis.IStream,
+        *,
+        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+    ) -> None:
         '''
-        :param stream: -
+        :param stream: The Kinesis stream to use as destination.
+        :param role: The role to assume to write log events to the destination. Default: - A new Role is created
         '''
-        jsii.create(self.__class__, self, [stream])
+        props = KinesisDestinationProps(role=role)
+
+        jsii.create(self.__class__, self, [stream, props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -77,6 +93,57 @@ class KinesisDestination(
         return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, _source_log_group]))
 
 
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-logs-destinations.KinesisDestinationProps",
+    jsii_struct_bases=[],
+    name_mapping={"role": "role"},
+)
+class KinesisDestinationProps:
+    def __init__(self, *, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
+        '''Customize the Kinesis Logs Destination.
+
+        :param role: The role to assume to write log events to the destination. Default: - A new Role is created
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_iam as iam
+            import aws_cdk.aws_logs_destinations as logs_destinations
+            
+            # role: iam.Role
+            
+            kinesis_destination_props = logs_destinations.KinesisDestinationProps(
+                role=role
+            )
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if role is not None:
+            self._values["role"] = role
+
+    @builtins.property
+    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+        '''The role to assume to write log events to the destination.
+
+        :default: - A new Role is created
+        '''
+        result = self._values.get("role")
+        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "KinesisDestinationProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(aws_cdk.aws_logs.ILogSubscriptionDestination)
 class LambdaDestination(
     metaclass=jsii.JSIIMeta,
@@ -190,6 +257,7 @@ class LambdaDestinationOptions:
 
 __all__ = [
     "KinesisDestination",
+    "KinesisDestinationProps",
     "LambdaDestination",
     "LambdaDestinationOptions",
 ]
